# Ask Schools

[
![PyPI](https://img.shields.io/pypi/v/sp_ask_chats_utils.svg)
![PyPI](https://img.shields.io/pypi/pyversions/sp_ask_chats_utils.svg)
![PyPI](https://img.shields.io/github/license/guinslym/sp_ask_chats_utils.svg)
](https://pypi.org/project/sp_ask_chats_utils/)
[![TravisCI](https://travis-ci.org/guinslym/sp_ask_chats_utils.svg?branch=master)](https://travis-ci.org/guinslym/sp_ask_chats_utils)


This package helps to filter Chats


## Installation

**Ask Schools** can be installed from PyPI using `pip` or your package manager of choice:

```
pip install sp_ask_chats_utils
```

## Usage


Example:

```python

from sp_ask_chats_utils import remove_practice_queues

chats = remove_practice_queues(chats):

```

## Code of Conduct

Everyone interacting in the project's codebases, issue trackers, chat rooms, and mailing lists is expected to follow the [PyPA Code of Conduct](https://www.pypa.io/en/latest/code-of-conduct/).
